require "spec_helper"

require "config_hound/resource"
require "uri"

describe ConfigHound::Resource do

  let(:resource) { described_class[path] }

  context "with a URI" do

    let(:uri) { URI("http://example.com/some_uri") }
    let(:path) { uri }

    it "retains the URI" do
      expect(resource.uri).to eq uri
    end

  end

  context "with a fully-qualified path" do

    let(:path) { "/path/to/file" }

    it "assumes it's a file" do
      expect(resource.uri).to eq URI("file:///path/to/file")
    end

    describe "#resolve" do

      context "with a relative path" do
        it "resolves relatively" do
          other_resource = resource.resolve("other_file")
          expect(other_resource).to be_a(ConfigHound::Resource)
          expect(other_resource.uri).to eq URI("file:///path/to/other_file")
        end
      end

      context "with an absolute file path" do
        it "resolves relatively" do
          other_resource = resource.resolve("/different/path")
          expect(other_resource.uri).to eq URI("file:///different/path")
        end
      end

      context "with a fully-qualified URI" do
        it "uses the URI provided" do
          other_resource = resource.resolve("http://foo/bar")
          expect(other_resource.uri).to eq URI("http://foo/bar")
        end
      end

    end

  end

  context "with a relative path" do

    let(:path) { "config.yml" }

    it "assumes it's a file relative to $CWD" do
      expect(resource.uri).to eq URI("file://#{Dir.pwd}/config.yml")
    end

  end

end
